<?php

declare(strict_types=1);

namespace Drupal\panther;

class Settings {

  private string $loginUrl;
  private string $logoutUrl;
  private string $logIn;
  private string $logOut;
  private string $usernameField;
  private string $passwordField;

  public function __construct() {
    $this->loginUrl = $this->getValueFromEnvOrDefault('PANTHER_DRUPAL_LOGIN_URL', '/user');
    $this->logoutUrl = $this->getValueFromEnvOrDefault('PANTHER_DRUPAL_LOGOUT_URL', '/user/logout');
    $this->logIn = $this->getValueFromEnvOrDefault('PANTHER_DRUPAL_LOGIN_BUTTON', 'Log in');
    $this->logOut = $this->getValueFromEnvOrDefault('PANTHER_DRUPAL_LOGOUT_BUTTON', 'Log out');
    $this->usernameField = $this->getValueFromEnvOrDefault('PANTHER_DRUPAL_USERNAME_FIELD', 'name');
    $this->passwordField = $this->getValueFromEnvOrDefault('PANTHER_DRUPAL_PASSWORD_FIELD', 'pass');
  }

  /**
   * Return the URL of the login page.
   */
  public function getLoginUrl(): string {
    return $this->loginUrl;
  }

  /**
   * Return the URL of the logout page.
   */
  public function getLogoutUrl(): string {
    return $this->logoutUrl;
  }

  /**
   * Return the value of the login button.
   */
  public function getLogIn(): string {
    return $this->logIn;
  }

  /**
   * Return the value of the logout button.
   */
  public function getLogOut(): string {
    return $this->logOut;
  }

  /**
   * Return the name of the username field.
   */
  public function getUsernameField(): string {
    return $this->usernameField;
  }

  /**
   * Return the name of the password field.
   */
  public function getPasswordField(): string {
    return $this->passwordField;
  }

  private function getValueFromEnvOrDefault(string $env_name, string $default_value): string {
    $value = \getenv($env_name);
    if ($value === FALSE) {
      $value = $default_value;
    }

    return $value;
  }

}
